rbd_remove

Function rbd_remove 

pub unsafe extern "C" fn rbd_remove(
    io: rados_ioctx_t,
    name: *const c_char,
) -> c_int
Delete an RBD image. This may take a long time, since it does not return until every object that comprises the image has been deleted. Note that all snapshots must be deleted before the image can be removed.